==> jc-1.4.0.tar.gz: javax/swing/text/StringContent__24StickyPosition.h <==
// class javax.swing.text.StringContent$StickyPosition

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 27b5b59e2823c5cf javax_swing_text_StringContent__24StickyPosition

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StringContent__24StickyPosition_H_
#define _JC_javax_swing_text_StringContent__24StickyPosition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_StringContent$object;
struct _jc_javax_swing_text_StringContent__24StickyPosition$object;

// Typedefs
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_refs	_jc_javax_swing_text_StringContent__24StickyPosition$sub_refs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs	_jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$refs	_jc_javax_swing_text_StringContent__24StickyPosition$refs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$nonrefs	_jc_javax_swing_text_StringContent__24StickyPosition$nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$object	_jc_javax_swing_text_StringContent__24StickyPosition$object;

typedef const struct _jc_javax_swing_text_StringContent__24StickyPosition$vmethods	_jc_javax_swing_text_StringContent__24StickyPosition$vmethods;
typedef const struct _jc_javax_swing_text_StringContent__24StickyPosition$vtable	_jc_javax_swing_text_StringContent__24StickyPosition$vtable;
typedef const struct _jc_javax_swing_text_StringContent__24StickyPosition$vtype	_jc_javax_swing_text_StringContent__24StickyPosition$vtype;

// Constructors
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$_init$5418e33a73d46cae(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, struct _jc_javax_swing_text_StringContent$object *, jint);

// Virtual methods
extern jint _jc_javax_swing_text_StringContent__24StickyPosition$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *);
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$setOffset$8f9bca0c1b25f322(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, jint);
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StringContent__24StickyPosition$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_swing_text_StringContent__24StickyPosition$method_info$setOffset$8f9bca0c1b25f322;
extern _jc_method _jc_javax_swing_text_StringContent__24StickyPosition$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$access__240$6c62c1e287565779(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, jint);

// Virtual methods structure
struct _jc_javax_swing_text_StringContent__24StickyPosition$vmethods {
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *);
	void	(*setOffset$8f9bca0c1b25f322)(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *);
};

// Vtable
struct _jc_javax_swing_text_StringContent__24StickyPosition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StringContent__24StickyPosition$vmethods	javax_swing_text_StringContent__24StickyPosition;
};

// Vtype
struct _jc_javax_swing_text_StringContent__24StickyPosition$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StringContent__24StickyPosition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_refs {
	struct _jc_javax_swing_text_StringContent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24StickyPosition$refs {
    _jc_javax_swing_text_StringContent__24StickyPosition$sub_refs	javax_swing_text_StringContent__24StickyPosition;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs {
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24StickyPosition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs	javax_swing_text_StringContent__24StickyPosition;
};

// Object instance structure
struct _jc_javax_swing_text_StringContent__24StickyPosition$object {
	_jc_javax_swing_text_StringContent__24StickyPosition$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StringContent__24StickyPosition$vtype	*vtype;
	_jc_javax_swing_text_StringContent__24StickyPosition$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StringContent__24StickyPosition$vtype _jc_javax_swing_text_StringContent__24StickyPosition$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StringContent__24StickyPosition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StringContent__24StickyPosition$class_object;

#endif	/* _JC_javax_swing_text_StringContent__24StickyPosition_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StringContent__24StickyPosition.h <==
// class javax.swing.text.StringContent$StickyPosition

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a37f3833d9047b4b javax_swing_text_StringContent__24StickyPosition

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StringContent__24StickyPosition_H_
#define _JC_javax_swing_text_StringContent__24StickyPosition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_StringContent$object;

// Typedefs
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_refs	_jc_javax_swing_text_StringContent__24StickyPosition$sub_refs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs	_jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$refs	_jc_javax_swing_text_StringContent__24StickyPosition$refs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$nonrefs	_jc_javax_swing_text_StringContent__24StickyPosition$nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24StickyPosition$object	_jc_javax_swing_text_StringContent__24StickyPosition$object;

typedef const struct _jc_javax_swing_text_StringContent__24StickyPosition$vmethods	_jc_javax_swing_text_StringContent__24StickyPosition$vmethods;
typedef const struct _jc_javax_swing_text_StringContent__24StickyPosition$vtable	_jc_javax_swing_text_StringContent__24StickyPosition$vtable;
typedef const struct _jc_javax_swing_text_StringContent__24StickyPosition$vtype	_jc_javax_swing_text_StringContent__24StickyPosition$vtype;

// Constructors
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$_init$5418e33a73d46cae(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, struct _jc_javax_swing_text_StringContent$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_text_StringContent__24StickyPosition$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$setOffset$8f9bca0c1b25f322(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StringContent__24StickyPosition$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StringContent__24StickyPosition$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_swing_text_StringContent__24StickyPosition$method_info$setOffset$8f9bca0c1b25f322;
extern _jc_method _jc_javax_swing_text_StringContent__24StickyPosition$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_text_StringContent__24StickyPosition$vmethods {
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *) _JC_JCNI_ATTR;
	void	(*setOffset$8f9bca0c1b25f322)(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_text_StringContent__24StickyPosition$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StringContent__24StickyPosition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StringContent__24StickyPosition$vmethods	javax_swing_text_StringContent__24StickyPosition;
};

// Vtype
struct _jc_javax_swing_text_StringContent__24StickyPosition$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StringContent__24StickyPosition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_refs {
	struct _jc_javax_swing_text_StringContent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24StickyPosition$refs {
    _jc_javax_swing_text_StringContent__24StickyPosition$sub_refs	javax_swing_text_StringContent__24StickyPosition;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs {
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24StickyPosition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StringContent__24StickyPosition$sub_nonrefs	javax_swing_text_StringContent__24StickyPosition;
};

// Object instance structure
struct _jc_javax_swing_text_StringContent__24StickyPosition$object {
	_jc_javax_swing_text_StringContent__24StickyPosition$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StringContent__24StickyPosition$vtype	*vtype;
	_jc_javax_swing_text_StringContent__24StickyPosition$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StringContent__24StickyPosition$vtype _jc_javax_swing_text_StringContent__24StickyPosition$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StringContent__24StickyPosition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StringContent__24StickyPosition$class_object;

#endif	/* _JC_javax_swing_text_StringContent__24StickyPosition_H_ */
